max property

double max
final

The maximal measure on the radial scale for positive values.

If defined, all positive arcs will adjust to this maximum, otherwise the maximal positive measure among all domains will fit all available degrees of the circle, and other positive arcs will adjust to this measure.

It can't be less than zero, otherwise it'll be clamped to zero and none of positive arcs will be shown.

It's null by default.

Implementation

final double max;