scale property
The optional scale of the diagram.
If defined, all positive and negative arcs will adjust to these maximums, otherwise the maximums of negative and positive arcs will be calculated based on the data.
It can be useful to set the same scale for several diagrams to compare values between these diagrams.
It's null by default.
Implementation
final RadialScale? scale;