min property
The minimal measure on the radial scale for negative values.
If defined, all arcs will adjust to this minimum, otherwise the maximal positive measure among all domains will fit all available degrees of the circle, and other positive arcs will adjust to this measure.
It can't be more than zero, otherwise it'll be clamped to zero and none of negative arcs will be shown.
It's null by default.
Implementation
final double min;